import * as servicecatalog from 'aws-cdk-lib/aws-servicecatalog';
import { Construct } from 'constructs';
/**
 * Interface for Service Catalog of EMR cluster templates.
 */
export interface EmrStudioDeveloperStackProps {
    /**
                                                     * The provider name in a Service Catalog for EMR cluster templates.
                                                     *
                                                     * @default - 'scott.hsieh'
                                                     */
    readonly providerName?: string;
}
/**
 * Creates a Service Catalog for EMR cluster templates.
 *
 * For detail, please refer to [Create AWS CloudFormation templates for Amazon EMR Studio](https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-studio-cluster-templates.html).
 *
 * ```ts
 * const emrClusterTemplatePortfolio = new EmrStudioDeveloperStack(this, 'ClusterTempalte');
 * ```
 */
export declare class EmrStudioDeveloperStack extends Construct {
    /**
                                                     * The representative of the service catalog for EMR cluster tempaltes.
                                                     */
    readonly portfolio: servicecatalog.Portfolio;
    /**
                                                     * The representative of the product for demo purpose.
                                                     */
    readonly product: servicecatalog.Product;
    constructor(scope: Construct, name: string, props?: EmrStudioDeveloperStackProps);
}
export declare class EmrClusterTemplateStack extends servicecatalog.ProductStack {
    constructor(scope: Construct, id: string);
}
//# sourceMappingURL=emr-studio-cluster-templates.d.ts.map